@@ -1,4 +1,4 @@
-# Copyright (C) 2004 Christoph Berg <cb@df7cb.de>
+# Copyright (C) 2004, 2005, 2006 Christoph Berg <cb@df7cb.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -9,13 +9,6 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-# 2004-07-04 cb: added links and cleaned up code
-# 2004-07-24 cb: added viewport
 
 package IrcMarkers::File;
 
@@ -191,6 +184,8 @@ sub parse {
 		$config->{overlap_correction} = 1;
 	} elsif(/^overlap_correction (off|no)/) {
 		$config->{overlap_correction} = 0;
+	} elsif(/^recv(?:-keys)/) {
+		$config->{recv} = 1;
 	} elsif(/^quiet (on|yes)/) {
 		$config->{quiet} = 1;
 	} elsif(/^quiet (off|no)/) {
@@ -262,6 +257,10 @@ sub get_gpg_links {
 	my $config = shift;
 
 	my $keys = join ' ', keys %{$config->{gpg}};
+	if ($config->{recv}) {
+		system "gpg --recv-keys $keys";
+	}
+
 	open GPG, "gpg --list-sigs --with-colon --fixed-list-mode --fast-list-mode $keys |" or die "gpg: $!";
 	my ($key, $src);
 	while(<GPG>) {
