@@ -1,4 +1,4 @@
-# Copyright (C) 2004 Christoph Berg <cb@df7cb.de>
+# Copyright (C) 2004, 2005, 2006 Christoph Berg <cb@df7cb.de>
 #
 # This file originated from the mapmarkers distribution:
 #
@@ -14,13 +14,6 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-# 2004-07-04 cb: added links and cleaned up code
-# 2004-07-24 cb: added viewport
 
 package IrcMarkers::Map;
 
@@ -190,7 +183,7 @@ sub compute_overlap {
 		my $marker = $config->{markers}->[$m];
 		next unless $marker->{visible};
 		next if $marker->{text} eq "";
-		my $ref = $marker->{LABEL_BOUNDS} or die;
+		my $ref = $marker->{LABEL_BOUNDS} or die; # TODO: use real bounds here
 		printf W ("%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
 					$m,
 					$marker->{x},
@@ -201,10 +194,10 @@ sub compute_overlap {
 					$marker->{y} + $marker->{dot_size},
 					2 * $marker->{dot_size},
 					2 * $marker->{dot_size},
-					$ref->[0], # left x
-					$ref->[2], # right x
-					$ref->[5], # upper y
-					$ref->[1], # lower y
+					$marker->{x} + $ref->[0], # left x
+					$marker->{x} + $ref->[2], # right x
+					$marker->{y} + $ref->[5], # upper y
+					$marker->{y} + $ref->[1], # lower y
 					$ref->[2] - $ref->[0], # width
 					$ref->[1] - $ref->[5]  # height
 		);
